Index: /issm/trunk/cron/nightlyrun.sh
===================================================================
--- /issm/trunk/cron/nightlyrun.sh	(revision 5068)
+++ /issm/trunk/cron/nightlyrun.sh	(revision 5069)
@@ -40,5 +40,5 @@
 #Get configuration
 #Check that no other nightly run is running {{{1
-if [ "$(ps aux | grep "nighltyrun\.sh" | grep -v "grep")" ]
+if [ "$(ps aux | grep "nightlyrun\.sh" | grep -v "grep")" ]
 then
 	echo "WARNING: A nightly run is already running. Killing..."
@@ -224,11 +224,11 @@
 fi
 #}}}
 #Create TEMP directory and nightly.log {{{1
 #put installation elapsed time in nightly.log
 INSTALL_TIME=$(timer)
 ELAPSED_INSTALL=$(timer $START_TIME)
-rm -rf $ISSM_DIR/TEMP
-mkdir  $ISSM_DIR/TEMP
-cat << END > $ISSM_DIR/TEMP/nightly.log
+rm -rf $ISSM_DIR/nightlylog
+mkdir  $ISSM_DIR/nightlylog
+cat << END > $ISSM_DIR/nightlylog/nightly.log
 today:     $(echo $TODAY)
 user:      $(echo $USER)
@@ -249,5 +249,5 @@
 ELAPSED_RUN=$(timer $INSTALL_TIME)
 ELAPSED_TOTAL=$(timer $START_TIME)
-cat << END >>  $ISSM_DIR/TEMP/nightly.log
+cat << END >>  $ISSM_DIR/nightlylog/nightly.log
 elapsed_run:   $(echo $ELAPSED_RUN)
 elapsed_total: $(echo $ELAPSED_TOTAL)
@@ -259,5 +259,5 @@
 cd $ISSM_DIR/cron/
 ./report2.sh
-echo "html report located in $ISSM_DIR/TEMP/report.html"
+echo "html report located in $ISSM_DIR/nightlylog/report.html"
 #}}}
 #send mail if requested                  (SKIPMAIL) {{{1
@@ -274,5 +274,5 @@
 			if [ "$OS" = "linux64" ]
 			then
-cat - $ISSM_DIR/TEMP/report.html <<HERE | /usr/lib/sendmail  -oi -t
+cat - $ISSM_DIR/nightlylog/report.html <<HERE | /usr/lib/sendmail  -oi -t
 From: "ISSM Nightly run" <$EMAIL_ADRESS>
 To: $i
@@ -282,5 +282,5 @@
 HERE
 		else
-cat - $ISSM_DIR/TEMP/report.html <<HERE | /usr/sbin/sendmail  -oi -t
+cat - $ISSM_DIR/nightlylog/report.html <<HERE | /usr/sbin/sendmail  -oi -t
 From: "ISSM Nightly run" <$EMAIL_ADRESS>
 To: $i
@@ -224,11 +224,11 @@
 fi
 #}}}
-#Create TEMP directory and nightly.log {{{1
+#Create nightlylog directory and nightly.log {{{1
 #put installation elapsed time in nightly.log
 INSTALL_TIME=$(timer)
